==> haskell-tasty-ant-xml-1.1.8-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-ant-xml
version:              1.1.8
visibility:           public
id:                   tasty-ant-xml-1.1.8-1rTsSiOUpU2HyTziDHo5Ur
key:                  tasty-ant-xml-1.1.8-1rTsSiOUpU2HyTziDHo5Ur
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  9bc1cf8dd7bf7c27948d873c7af01ccb
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-ant-xml-1.1.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-ant-xml-1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.8-1rTsSiOUpU2HyTziDHo5Ur
depends:
    base-4.15.1.0 containers-0.6.4.1 directory-1.3.6.2 filepath-1.4.2.1
    generic-deriving-1.14.1-8UON3N72rpAHMp9XRKu0UQ ghc-prim-0.7.0
    mtl-2.2.2 stm-2.5.0.0 tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.1-569u2j830A77XiRQX8gZTx transformers-0.5.6.2
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-ant-xml-1.1.8-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-ant-xml
version:              1.1.8
visibility:           public
id:                   tasty-ant-xml-1.1.8-DgMIku6mEHo7HEajJZB8Kt
key:                  tasty-ant-xml-1.1.8-DgMIku6mEHo7HEajJZB8Kt
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  818e5ce96f2204860d793aea0f795993
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-ant-xml-1.1.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-ant-xml-1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.8-DgMIku6mEHo7HEajJZB8Kt
depends:
    base-4.15.1.0 containers-0.6.4.1 directory-1.3.6.2 filepath-1.4.2.1
    generic-deriving-1.14.1-4gTRv7GUUsg1K8BTwynDWE ghc-prim-0.7.0
    mtl-2.2.2 stm-2.5.0.0 tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.2-AfkvjgAgyIO8Wpi2IVD0lg transformers-0.5.6.2
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
